@@ -3,6 +3,7 @@
 from dbaas_zabbix.dbaas_api import DatabaseAsAServiceApi
 from dbaas_zabbix.provider_factory import ProviderFactory
 from pyzabbix import ZabbixAPI
+from dbaas_zabbix.provider import ZabbixProvider
 
 
 def factory_for(**kwargs):
@@ -18,4 +19,6 @@ def factory_for(**kwargs):
 
     dbaas_api = DatabaseAsAServiceApi(databaseinfra, credentials)
 
+    # TUDO ISSO PRA RETORNAR...
+    # ZabbixProvider(dbaas_api=dbaas_api, zabbix_api=zabbix_api, **kwargs)
     return ProviderFactory.factory(dbaas_api, zabbix_api=zabbix_api, **kwargs)
