@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import logging
+import requests
 
 LOG = logging.getLogger(__name__)
 STATUS_ENABLE = 0
@@ -44,7 +45,20 @@ class ZabbixProvider(object):
         self.dbaas_api = dbaas_api
         self.api = zabbix_api(dbaas_api.endpoint)
         self.api.session.verify=False
-        self.api.login(user=dbaas_api.user, password=dbaas_api.password)
+        self.api._login(user=dbaas_api.user, password=dbaas_api.password)
+
+    def _login(self, user, password, endpoint=""):
+
+        zabbix_auth_endpoint = 'https://api.zabbix.staging.globoi.com/api/v4/user/Login'
+        headers = {'Content-Type': 'application/json'} 
+        data = { "params" : { "user": user, "password": password}}
+        r = requests.post(zabbix_auth_endpoint, json=data, headers=headers, verify=False)
+
+        if r.status_code == 200 or r.status_code == 201:
+            r_data = r.json()
+            token = r_data['result']
+            self.api.auth = token
+
 
     @property
     def zabbix_version(self):
